import { useState } from "react";
import { useQuery, useMutation } from "@tanstack/react-query";
import { useLocation, Link } from "wouter";
import { apiRequest, queryClient } from "@/lib/queryClient";
import { useToast } from "@/hooks/use-toast";
import { Avatar, AvatarFallback } from "@/components/ui/avatar";
import { Button } from "@/components/ui/button";
import {
  Card,
  CardContent,
  CardDescription,
  CardHeader,
  CardTitle,
} from "@/components/ui/card";
import {
  Tabs,
  TabsContent,
  TabsList,
  TabsTrigger,
} from "@/components/ui/tabs";
import ListingGrid from "@/components/listing/ListingGrid";
import { Edit, LogOut, MessageSquare, Heart, ListChecks } from "lucide-react";
import { formatDistanceToNow } from "date-fns";
import { fr } from "date-fns/locale";

interface Listing {
  id: number;
  title: string;
  price: number | null;
  description: string;
  location: string;
  createdAt: string;
  isUrgent?: boolean;
  primaryImage?: string | null;
  userId: number;
}

const UserProfile = () => {
  const [, navigate] = useLocation();
  const { toast } = useToast();
  const [activeTab, setActiveTab] = useState("listings");

  // Fetch current user
  const {
    data: userData,
    isLoading: isUserLoading,
    error: userError,
  } = useQuery<{ user: any }>({
    queryKey: ['/api/auth/current-user'],
  });

  // Redirect if not logged in
  if (!isUserLoading && !userData?.user) {
    navigate("/login");
    return null;
  }

  // Fetch user's listings
  const {
    data: userListingsData,
    isLoading: isListingsLoading,
  } = useQuery<{ listings: Listing[] }>({
    queryKey: [`/api/listings/user/${userData?.user?.id}`],
    enabled: !!userData?.user?.id,
  });

  // Fetch user's favorites
  const {
    data: favoritesData,
    isLoading: isFavoritesLoading,
  } = useQuery<{ listings: Listing[] }>({
    queryKey: ['/api/favorites'],
    enabled: !!userData?.user?.id,
  });

  // Fetch user's messages
  const {
    data: messagesData,
    isLoading: isMessagesLoading,
  } = useQuery<{ messages: any[] }>({
    queryKey: ['/api/messages'],
    enabled: !!userData?.user?.id,
  });

  // Logout mutation
  const logoutMutation = useMutation({
    mutationFn: async () => {
      await apiRequest('POST', '/api/auth/logout', {});
    },
    onSuccess: () => {
      queryClient.invalidateQueries({ queryKey: ['/api/auth/current-user'] });
      toast({
        title: "Déconnexion réussie",
        description: "Vous avez été déconnecté avec succès.",
      });
      navigate("/");
    },
    onError: () => {
      toast({
        title: "Erreur",
        description: "Une erreur est survenue lors de la déconnexion.",
        variant: "destructive",
      });
    },
  });

  // Handle logout
  const handleLogout = () => {
    logoutMutation.mutate();
  };

  const isLoading = isUserLoading || isListingsLoading || isFavoritesLoading || isMessagesLoading;

  if (isLoading) {
    return (
      <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8 py-8">
        <div className="grid grid-cols-1 gap-6">
          <div className="bg-gray-100 rounded-lg h-40 animate-pulse"></div>
          <div className="bg-gray-100 rounded-lg h-[400px] animate-pulse"></div>
        </div>
      </div>
    );
  }

  const user = userData?.user;
  const listings = userListingsData?.listings || [];
  const favorites = favoritesData?.listings || [];
  const messages = messagesData?.messages || [];

  return (
    <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8 py-8">
      {/* User Profile Card */}
      <Card className="mb-8">
        <CardContent className="pt-6">
          <div className="flex flex-col md:flex-row md:items-center md:justify-between">
            <div className="flex items-center">
              <Avatar className="h-16 w-16 mr-4">
                <AvatarFallback className="bg-primary text-white text-xl">
                  {user.username.charAt(0).toUpperCase()}
                </AvatarFallback>
              </Avatar>
              <div>
                <h1 className="text-2xl font-bold">{user.username}</h1>
                <p className="text-gray-500">
                  {user.isPro ? "Professionnel" : "Particulier"}
                </p>
                <p className="text-sm text-gray-500">
                  Membre depuis {formatDistanceToNow(new Date(user.createdAt), { addSuffix: true, locale: fr })}
                </p>
              </div>
            </div>
            <div className="mt-4 md:mt-0 flex space-x-2">
              <Button variant="outline" size="sm" className="flex items-center">
                <Edit className="mr-2 h-4 w-4" />
                Modifier le profil
              </Button>
              <Button
                variant="outline"
                size="sm"
                className="flex items-center"
                onClick={handleLogout}
                disabled={logoutMutation.isPending}
              >
                <LogOut className="mr-2 h-4 w-4" />
                Déconnexion
              </Button>
            </div>
          </div>
        </CardContent>
      </Card>

      {/* User Content Tabs */}
      <Tabs
        defaultValue="listings"
        value={activeTab}
        onValueChange={setActiveTab}
        className="w-full"
      >
        <TabsList className="grid grid-cols-3 w-full max-w-md mb-8">
          <TabsTrigger value="listings" className="flex items-center justify-center">
            <ListChecks className="mr-2 h-4 w-4" />
            Mes annonces
          </TabsTrigger>
          <TabsTrigger value="favorites" className="flex items-center justify-center">
            <Heart className="mr-2 h-4 w-4" />
            Favoris
          </TabsTrigger>
          <TabsTrigger value="messages" className="flex items-center justify-center">
            <MessageSquare className="mr-2 h-4 w-4" />
            Messages
          </TabsTrigger>
        </TabsList>

        <TabsContent value="listings">
          <Card>
            <CardHeader>
              <CardTitle>Mes annonces</CardTitle>
              <CardDescription>
                Gérez vos annonces publiées sur Gwadacoin
              </CardDescription>
            </CardHeader>
            <CardContent>
              <div className="mb-4">
                <Button asChild>
                  <Link href="/create-listing">Déposer une nouvelle annonce</Link>
                </Button>
              </div>
              
              <ListingGrid
                listings={listings}
                loading={isListingsLoading}
                emptyMessage="Vous n'avez pas encore publié d'annonces"
              />
            </CardContent>
          </Card>
        </TabsContent>

        <TabsContent value="favorites">
          <Card>
            <CardHeader>
              <CardTitle>Mes favoris</CardTitle>
              <CardDescription>
                Toutes les annonces que vous avez ajoutées à vos favoris
              </CardDescription>
            </CardHeader>
            <CardContent>
              <ListingGrid
                listings={favorites}
                loading={isFavoritesLoading}
                emptyMessage="Vous n'avez pas encore d'annonces en favoris"
              />
            </CardContent>
          </Card>
        </TabsContent>

        <TabsContent value="messages">
          <Card>
            <CardHeader>
              <CardTitle>Mes messages</CardTitle>
              <CardDescription>
                Vos conversations avec les vendeurs et acheteurs
              </CardDescription>
            </CardHeader>
            <CardContent>
              {messages.length > 0 ? (
                <div className="divide-y">
                  {messages.map((message) => (
                    <div key={message.id} className="py-4">
                      <div className="flex justify-between items-start mb-2">
                        <div className="font-medium">
                          {message.senderId === user.id ? "Envoyé à" : "Reçu de"}: 
                          {message.senderId === user.id ? message.receiverId : message.senderId}
                        </div>
                        <div className="text-sm text-gray-500">
                          {formatDistanceToNow(new Date(message.createdAt), {
                            addSuffix: true,
                            locale: fr,
                          })}
                        </div>
                      </div>
                      <p className="text-gray-700">{message.content}</p>
                      <div className="mt-2">
                        <Link href={`/listings/${message.listingId}`} className="text-sm text-accent hover:underline">
                          Voir l'annonce
                        </Link>
                      </div>
                    </div>
                  ))}
                </div>
              ) : (
                <div className="text-center py-10">
                  <p className="text-gray-500">Vous n'avez pas encore de messages</p>
                </div>
              )}
            </CardContent>
          </Card>
        </TabsContent>
      </Tabs>
    </div>
  );
};

export default UserProfile;
